/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.filter;

import org.w3c.css.sac.AttributeCondition;
import org.w3c.dom.Element;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: AttributeFilter.java,v 1.1 2005/07/28 16:01:57 Teletha Exp $
 */
public class AttributeFilter implements Filter, AttributeCondition {

    /** The name. */
    protected String name = null;

    /** The value. */
    protected String value = null;

    /**
     * Create AttributeFilter instance.
     * 
     * @param name An attribute name.
     * @param value An attribute value.
     */
    public AttributeFilter(String name, String value) {
        // check null
        if (name != null && name.length() != 0) {
            this.name = name;
        }
        this.value = value;
    }

    /**
     * @see org.trix.cuery.filter.Filter#accept(org.w3c.dom.Element)
     */
    public boolean accept(Element target) {
        // check null
        if (target == null || name == null) {
            return false;
        }

        String attribute = target.getAttribute(name);

        // check attribute
        if (attribute == null || attribute.length() == 0) {
            return false;
        }
        return acceptAttribute(attribute);
    }

    /**
     * @see org.trix.cuery.filter.Filter#getSpecificity()
     */
    public int getSpecificity() {
        return 10;
    }

    /**
     * @see org.trix.cuery.filter.Filter#getState()
     */
    public int getState() {
        return 0;
    }

    /**
     * @see org.w3c.css.sac.Condition#getConditionType()
     */
    public short getConditionType() {
        return SAC_ATTRIBUTE_CONDITION;
    }

    /**
     * @see org.w3c.css.sac.Selector#getSelectorType()
     */
    public short getSelectorType() {
        return SAC_CONDITIONAL_SELECTOR;
    }

    /**
     * @see org.w3c.css.sac.AttributeCondition#getLocalName()
     */
    public String getLocalName() {
        return name;
    }

    /**
     * @see org.w3c.css.sac.AttributeCondition#getNamespaceURI()
     */
    public String getNamespaceURI() {
        return null;
    }

    /**
     * @see org.w3c.css.sac.AttributeCondition#getSpecified()
     */
    public boolean getSpecified() {
        return false;
    }

    /**
     * @see org.w3c.css.sac.AttributeCondition#getValue()
     */
    public String getValue() {
        return value;
    }

    /**
     * Check that the target attribute value fills the condition.
     * 
     * @param attributeValue A target attribute value.
     * @return A result.
     */
    protected boolean acceptAttribute(String attributeValue) {
        if (value == null) {
            return true;
        }
        return value.equals(attributeValue);
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString() {
        if (value == null) {
            return "[" + name + "]";
        } else {
            return "[" + name + "=\"" + value + "\"]";
        }
    }

}
