/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.filter;

import org.trix.cuery.util.DOMUtil;

import org.w3c.dom.Element;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: FirstTypedFilter.java,v 1.0 2005/08/02 21:02:51 Teletha Exp $
 */
public final class FirstTypedFilter extends AbstractPseudoFilter {

    /** The singleton instance. */
    public static final FirstTypedFilter SINGLETON = new FirstTypedFilter();

    /**
     * Avoid creating FirstTypedFilter instance.
     */
    private FirstTypedFilter() {
    }

    /**
     * @see org.trix.cuery.filter.Filter#accept(org.w3c.dom.Element)
     */
    public boolean accept(Element target) {
        String ns = target.getNamespaceURI();
        String name = target.getLocalName();
        Element previous = DOMUtil.getPreviousElement(target);

        while (previous != null) {
            // check namespace
            if ((ns == null || ns.equals(previous.getNamespaceURI())) && name.equals(previous.getLocalName())) {
                return false;
            }
            previous = DOMUtil.getPreviousElement(previous);
        }
        return true;
    }

    /**
     * @see org.trix.cuery.filter.AbstractPseudoFilter#getPseudoName()
     */
    protected String getPseudoName() {
        return "first-of-type";
    }
}
