/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.filter;

import java.util.Set;

import org.trix.cuery.util.DOMUtil;

import org.w3c.css.sac.Selector;
import org.w3c.css.sac.SimpleSelector;
import org.w3c.dom.Element;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: IndirectAdjacentFilter.java,v 1.0 2005/08/04 23:43:34 Teletha Exp $
 */
public class IndirectAdjacentFilter extends DirectAdjacentFilter {

    /**
     * Create IndirectAdjacentFilter instance.
     * 
     * @param nodeType A node type.
     * @param parent A parent selector.
     * @param current A current selector.
     */
    public IndirectAdjacentFilter(short nodeType, Selector parent, SimpleSelector current) {
        super(nodeType, parent, current);
    }

    /**
     * @see org.trix.cuery.filter.DirectAdjacentFilter#process(java.util.Set, org.w3c.dom.Element)
     */
    public void process(Set container, Element source) {
        Element next = DOMUtil.getNextElement(source);

        while (next != null) {
            if (current.accept(next)) {
                container.add(next);
            }
            next = DOMUtil.getNextElement(next);
        }
    }

    /**
     * @see org.trix.cuery.filter.DirectAdjacentFilter#toString()
     */
    public String toString() {
        return parent + " ~ " + current;
    }

}
