/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.filter;

import org.w3c.css.sac.CSSException;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: LastTypedNumeralFilter.java,v 1.0 2005/07/27 16:01:01 Teletha Exp $
 */
public class LastTypedNumeralFilter extends AbstractNumeralFilter {

    /**
     * Create LastTypedNumeralFilter instance.
     * 
     * @param argument An argument.
     * @throws CSSException If the argument is invalid pattern.
     */
    public LastTypedNumeralFilter(String argument) throws CSSException {
        super(argument);
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString() {
        return ":nth-last-of-type(" + argument + ")";
    }

    /**
     * @see org.trix.cuery.filter.AbstractNumeralFilter#getPosition(org.w3c.dom.Element)
     */
    protected int getPosition(Element target) {
        // check parent
        Node parent = target.getParentNode();

        if (parent == null || parent.getNodeType() != Node.ELEMENT_NODE) {
            return -1;
        }

        int position = 1;
        String ns = target.getNamespaceURI();
        String name = target.getLocalName();
        NodeList nodeList = parent.getChildNodes();

        for (int i = nodeList.getLength() - 1; i > -1; i--) {
            Node node = nodeList.item(i);

            // check element
            if (node.getNodeType() != Node.ELEMENT_NODE) {
                continue;
            }

            Element current = (Element) node;

            // check namespace
            if (ns != null && !ns.equals(current.getNamespaceURI())) {
                continue;
            }

            // check local name
            if (!current.getLocalName().equals(name)) {
                continue;
            }

            // cehck
            if (current == target) {
                return position;
            }
            position++;
        }
        return -1;
    }

}
