/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.property.css2;

import org.trix.cuery.property.Property;
import org.trix.cuery.property.PropertyDefinition;
import org.trix.cuery.property.PropertyRegistry;
import org.trix.cuery.value.CSSLength;
import org.trix.cuery.value.CSSPercentage;
import org.trix.cuery.value.CSSValue;
import org.trix.cuery.value.Identifier;
import org.trix.cuery.value.ValueUtil;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: LineHeightDefinition.java,v 1.0 2005/09/09 2:15:14 Teletha Exp $
 */
public class LineHeightDefinition extends PropertyDefinition {

    /**
     * @see org.trix.cuery.property.PropertyDefinition#computeIdentifier(org.trix.cuery.value.Identifier,
     *      org.trix.cuery.property.Property, org.trix.cuery.property.Property)
     */
    protected CSSValue computeIdentifier(Identifier identifier, Property property, Property parent) {
        if (identifier.getCssText().equals("normal")) {
            CSSLength fontSize = (CSSLength) property.getValue("font-size");
            return ValueUtil.multiply(fontSize, PropertyRegistry.getFontConfiguration().getLineHeightFactor());
        }
        return identifier;
    }

    /**
     * @see org.trix.cuery.property.PropertyDefinition#computePercentage(org.trix.cuery.value.CSSPercentage,
     *      org.trix.cuery.property.Property, org.trix.cuery.property.Property)
     */
    protected CSSValue computePercentage(CSSPercentage percentage, Property property, Property parent) {
        CSSLength fontSize = (CSSLength) property.getValue("font-size");
        return ValueUtil.multiply(fontSize, percentage);
    }

}
